@@ -9,7 +9,7 @@
 #
 package Reindeer;
 {
-  $Reindeer::VERSION = '0.011';
+  $Reindeer::VERSION = '0.012';
 }
 
 # ABSTRACT: Moose with more antlers
@@ -22,6 +22,7 @@ use Moose::Exporter;
 use Class::Load;
 
 use MooseX::Traits ();
+use Moose::Util::TypeConstraints ();
 
 my (undef, undef, $init_meta) = Moose::Exporter->build_import_methods(
     install => [ qw{ import unimport } ],
@@ -44,6 +45,10 @@ sub init_meta {
     Reindeer::Util->import_type_libraries({ -into => $for_class });
     Path::Class->export_to_level(1);
     Try::Tiny->export_to_level(1);
+    Moose::Util::TypeConstraints->import(
+        { into => $for_class },
+        qw{ class_type role_type duck_type },
+    );
     MooseX::MarkAsMethods->import({ into => $for_class }, autoclean => 1);
 
     goto $init_meta if $init_meta;
@@ -57,13 +62,16 @@ sub init_meta {
 
 =encoding utf-8
 
+=for :stopwords Chris Weyl AutoDestruct MultiInitArg UndefTolerant autoclean rwp ttl
+metaclass Specifing
+
 =head1 NAME
 
 Reindeer - Moose with more antlers
 
 =head1 VERSION
 
-This document describes version 0.011 of Reindeer - released April 26, 2012 as part of Reindeer.
+This document describes version 0.012 of Reindeer - released June 12, 2012 as part of Reindeer.
 
 =head1 SYNOPSIS
 
@@ -87,15 +95,6 @@ a number of the more useful/popular extensions already applied.  Reindeer is a
 drop-in replacement for your "use Moose" line, that behaves in the exact same
 way... Just with more pointy antlers.
 
-=for stopwords AutoDestruct
-MultiInitArg
-UndefTolerant
-autoclean
-rwp
-ttl
-metaclass
-Specifing
-
 =for Pod::Coverage     init_meta
 
 =head1 EARLY RELEASE!
@@ -226,6 +225,38 @@ builder naming scheme (just with a different prefix).
 In addition to all sugar provided by L<Moose> (e.g. has, with, extends), we
 provide a couple new keywords.
 
+=head2 B<class_type ($class, ?$options)>
+
+Creates a new subtype of C<Object> with the name C<$class> and the
+metaclass L<Moose::Meta::TypeConstraint::Class>.
+
+  # Create a type called 'Box' which tests for objects which ->isa('Box')
+  class_type 'Box';
+
+By default, the name of the type and the name of the class are the same, but
+you can specify both separately.
+
+  # Create a type called 'Box' which tests for objects which ->isa('ObjectLibrary::Box');
+  class_type 'Box', { class => 'ObjectLibrary::Box' };
+
+(See also L<Moose::Util::TypeConstraints>.)
+
+=head2 B<role_type ($role, ?$options)>
+
+Creates a C<Role> type constraint with the name C<$role> and the
+metaclass L<Moose::Meta::TypeConstraint::Role>.
+
+  # Create a type called 'Walks' which tests for objects which ->does('Walks')
+  role_type 'Walks';
+
+By default, the name of the type and the name of the role are the same, but
+you can specify both separately.
+
+  # Create a type called 'Walks' which tests for objects which ->does('MooseX::Role::Walks');
+  role_type 'Walks', { role => 'MooseX::Role::Walks' };
+
+(See also L<Moose::Util::TypeConstraints>.)
+
 =head2 class_has => (...)
 
 Exactly like L<Moose/has>, but operates at the class (rather than instance)
